
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v6.007.
use strict;
use warnings;

use Module::Build 0.28;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.28"
  },
  "configure_requires" => {
    "Module::Build" => "0.28",
    "perl" => "v5.20.0"
  },
  "dist_abstract" => "Query a FreeBSD system for the list of mounted filesystems",
  "dist_author" => [
    "Athanasios Douitsis <aduitsis\@cpan.org>"
  ],
  "dist_name" => "FreeBSD-FsStat",
  "dist_version" => "0.104",
  "license" => "artistic_2",
  "module_name" => "FreeBSD::FsStat",
  "recursive_test_files" => 1,
  "requires" => {
    "DynaLoader" => 0,
    "Exporter" => 0,
    "Moose" => 0,
    "perl" => "v5.20.0",
    "strict" => 0,
    "vars" => 0,
    "warnings" => 0
  },
  "test_requires" => {
    "Data::Dumper" => 0,
    "Test::More" => 0,
    "perl" => "v5.20.0"
  }
);


my %fallback_build_requires = (
  "Data::Dumper" => 0,
  "Module::Build" => "0.28",
  "Test::More" => 0,
  "perl" => "v5.20.0"
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);


$build->create_build_script;
